@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # aptfs — FUSE filesystem for APT source repositories
-# Copyright © 2008—2016 Chris Lamb <lamby@debian.org>
+# Copyright © 2008—2017 Chris Lamb <lamby@debian.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@ from .download import download, DownloadError
 fuse.fuse_python_api = (0, 2)
 fuse.feature_assert('stateful_files', 'has_destroy')
 
+
 class AptFs(fuse.Fuse):
     def __init__(self, *args, **kwargs):
         fuse.Fuse.__init__(self, *args, **kwargs)
@@ -81,7 +82,7 @@ class AptFs(fuse.Fuse):
         if target is None:
             try:
                 target = download(pkg, self.temp_dir, self.secure)
-            except DownloadError, e:
+            except DownloadError as e:
                 shutil.rmtree(e.basedir)
                 raise
             self.source_packages[pkg] = target
@@ -108,7 +109,7 @@ class AptFs(fuse.Fuse):
                 st.st_nlink = 3
 
                 if pkg not in self.source_packages and \
-                    pkg not in self.binary_packages:
+                        pkg not in self.binary_packages:
                     return -errno.ENOENT
 
                 if pkg in self.binary_packages:
@@ -149,10 +150,12 @@ class AptFs(fuse.Fuse):
             yield fuse.Direntry('.')
             yield fuse.Direntry('..')
 
+            entries = self.source_packages
             if self.show_binary_symlinks:
-                entries = itertools.chain(self.source_packages, self.binary_packages)
-            else:
-                entries = self.source_packages
+                entries = itertools.chain(
+                    self.source_packages,
+                    self.binary_packages,
+                )
 
             for x in sorted(entries):
                 yield fuse.Direntry(x)
