@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # aptfs — FUSE filesystem for APT source repositories
-# Copyright © 2008—2016 Chris Lamb <lamby@debian.org>
+# Copyright © 2008—2017 Chris Lamb <lamby@debian.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,12 +20,14 @@ import os
 import commands
 import tempfile
 
+
 class DownloadError(Exception):
     def __init__(self, output, basedir):
         self.basedir = basedir
 
         super(DownloadError, self).__init__(self, output)
 
+
 def download(srcpkg, tempdir, secure=False):
     """
     Download and the specified source package and returns the base directory
@@ -47,10 +49,12 @@ def download(srcpkg, tempdir, secure=False):
     else:
         cmds = (
             'cd "%s"' % basedir,
-            'dget --quiet --download-only --allow-unauthenticated $(apt-get source ' + \
-                '--print-uris "%s" | sed -n "s/\'\(http[^\']*.dsc\).*/\\1/p")' % srcpkg,
+            'dget --quiet --download-only --allow-unauthenticated $(apt-get source ' +
+                '--print-uris "%s" | sed -n "s/\'\(http[^\']*.dsc\).*/\\1/p")' \
+                % srcpkg,
 
-            # Break the signature such that dpkg-source does not attempt to verify it.
+            # Break the signature such that dpkg-source does not attempt to
+            # verify it.
             'awk -v X=0 \'/^[ ]*$/ { X=1 } { if (X) print }\' *.dsc > src.dsc',
             'dpkg-source -x src.dsc unpacked',
         )
