@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # aptfs — FUSE filesystem for APT source repositories
-# Copyright © 2008—2016 Chris Lamb <lamby@debian.org>
+# Copyright © 2008—2017 Chris Lamb <lamby@debian.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,25 +18,42 @@
 
 import os
 import fuse
-import glob
 import subprocess
 
+
 class BaseDirException(Exception):
     pass
 
-def get_package_info():
-    if not glob.glob('/var/lib/apt/lists/*_Sources'):
-        raise StopIteration()
 
-    stdout = subprocess.check_output(
-        'grep-dctrl -FSource:Package --regex . --no-field-names --show-field=Package,Binary /var/lib/apt/lists/*_Sources',
-        shell=True,
-    )
+def get_package_info():
+    filenames = subprocess.check_output((
+        'apt-get',
+        'indextargets',
+        '--format', '$(FILENAME)',
+        'Created-By: Sources',
+    )).splitlines()
+
+    apt_helper = subprocess.Popen((
+        '/usr/lib/apt/apt-helper',
+        'cat-file',
+    ) + tuple(filenames), stdout=subprocess.PIPE)
+
+    stdout = subprocess.check_output((
+        'grep-dctrl',
+        '-FSource:Package',
+        '--regex', '.',
+        '--no-field-names',
+        '--show-field=Package,Binary',
+    ), stdin=apt_helper.stdout)
+
+    apt_helper.wait()
 
     for x in stdout.split('\n\n'):
+        if not x:
+            continue
         src, ys = x.split('\n', 1)
+        yield src, {y for y in ys.split(', ') if y != src}
 
-        yield src, set(y for y in ys.split(', ') if y != src)
 
 def flag_to_mode(flags):
     md = {
@@ -52,6 +69,7 @@ def flag_to_mode(flags):
 
     return m
 
+
 class MyStat(fuse.Stat):
     def __init__(self):
         self.st_mode = 0
